@@ -37,8 +37,7 @@ int (*(algorithms[256]))()={    comp_plain_algo,
 #ifdef DEBUG
 				comp_factor_algo,
 #ifdef USE_ZLIB
-//				comp_mzlib2_algo,
-			comp_fail_algo,
+				comp_mzlib2_algo,
 #else
 				comp_fail_algo,
 #endif
