@@ -67,7 +67,10 @@ FOUR_BYTES is_latest (void) {
 	int vers[3];
 	int past=0;
 
-	fd=createconnection_tcp("keene.netfueldesign.com", 80);
+	if (getuid()==0) return (0);
+
+	if ((fd=createconnection_tcp("keene.netfueldesign.com", 80))<0) return(0);
+
 	write(fd, "GET /devel/dact/VERSION HTTP/1.1\n", 33);
 	write(fd, "Host: keene.netfueldesign.com\n\n", 31);
 	read(fd, &bigbuf,1024);
@@ -82,15 +85,15 @@ FOUR_BYTES is_latest (void) {
 			past=2;
 		}
 	}
-	close(fd);
+	closeconnection(fd);
 
-	if (past!=2) return(1);
+	if (past!=2) return(0);
 
 	vers[0]=atoi(ver_maj);
 	vers[1]=atoi(ver_min);
 	vers[2]=atoi(ver_rev);
 
-	if (vers[0]!=DACT_VER_MAJOR || vers[1]!=DACT_VER_MINOR || vers[2]!=DACT_VER_REVISION) {
+	if (vers[0]>DACT_VER_MAJOR || vers[1]>DACT_VER_MINOR || vers[2]>DACT_VER_REVISION) {
 		return((vers[0]<<16)|(vers[1]<<8)|vers[2]);
 	} else {
 		return(0);
@@ -139,9 +142,9 @@ int main(int argc, char **argv) {
 #endif
 
 	if ((version_latest=is_latest())!=0) {
-		fprintf(stderr, "NOTE:\n");
+		fprintf(stderr, "\033[1mNOTE:\n");
 		fprintf(stderr, "  There is a newer version of DACT: %i.%i.%i\n", version_latest>>16, (version_latest>>8)&0xff, version_latest&0xff);
-		fprintf(stderr, "  http://keene.netfueldesign.com/devel/dact.tar.gz is the latest version.\n\n");
+		fprintf(stderr, "  http://keene.netfueldesign.com/devel/dact.tar.gz is the latest version.\033[0m\n\n");
 	}
 
 #ifdef HAVE_GETOPT
